# `narwhals`

Here are the top-level functions available in Narwhals.

::: narwhals
    handler: python
    options:
      members:
        - all
        - col
        - concat
        - from_native
        - len
        - max
        - mean
        - min
        - sum
        - sum_horizontal
        - to_native
      show_source: false
